======
boxmox
======

``boxmox`` is the Python wrapper for the chemical box model BOXMOX (a standalone
C/Fortran executable)

Documentation
=============

maintained at https://boxmodeling.meteo.physik.uni-muenchen.de/documentation

Installation
============

The chemical box model BOXMOX is required. See the documentation for
detailed instructions on how to install it.